{% load i18n %}
<div class="container pt-1 mx-auto">
    <div class="w-11/12 p-10 mx-auto mt-5 rounded-lg shadow-md md:mt-15 lg:mt-32 sm:p-5 md:w-6/12 lg:w-5/12 xl:w-4/12 md:p-10 xl:p-13 bg-base-100">
        <h1 class="mb-3 text-2xl">{{ heading }}</h1>
        {% if subheading %}<div>{{ subheading }}</div>{% endif %}
        {{ children }}
    </div>
</div>
