{% extends "account/password_reset_from_key.html" %}
{% load i18n %}
{% load allauth_ui %}
{% block content %}
    {% if token_fail %}
        {% trans "Bad Token" as heading %}
    {% else %}
        {% trans "Change Password" as heading %}
    {% endif %}
    {% #container heading=heading %}
    {% if token_fail %}
        {% url 'account_reset_password' as passwd_reset_url %}
        <div>
            {% blocktrans %}The password reset link was invalid, possibly because it has already been used.  Please request a <a href="{{ passwd_reset_url }}">new password reset</a>.{% endblocktrans %}
        </div>
    {% else %}
    {% endif %}
    {% trans "Change Password" as button_text %}
    {% url "account_reset_password_from_key" as action_url %}
    {% #form form=form url=action_url button_text=button_text %}
    {% csrf_token %}
    {{ redirect_field }}
    {% /form %}
    {% /container %}
{% endblock content %}
