{# -*- engine:django -*- #}
{% extends "account/confirm_login_code.html" %}
{% load i18n %}
{% load allauth %}
{% load allauth_ui %}
{% load widget_tweaks %}
{% block content %}
    {% trans "Sign In" as heading %}
    {% #container heading=heading  %}
    <div class="py-3">{% blocktranslate %}Enter Sign-In Code{% endblocktranslate %}</div>
    <div class="py-3">
        {% setvar email_link %}
        <a href="mailto:{{ email }}">{{ email }}</a>
    {% endsetvar %}
    {% blocktranslate %}We’ve sent a code to {{ email_link }}. The code expires shortly, so please enter it soon.{% endblocktranslate %}
</div>
{% url 'account_confirm_login_code' as action_url %}
{% #form form=form url=action_url button_text=heading %}
{{ redirect_field }}
{% csrf_token %}
{% /form %}
<button type="submit" class="btn btn-red" form="logout-from-stage">{% translate "Cancel" %}</button>
<form id="logout-from-stage"
      method="post"
      action="{% url 'account_logout' %}">
    <input type="hidden" name="next" value="{% url 'account_login' %}">
    {% csrf_token %}
</form>
{% /container %}
{% endblock content %}
{% comment %}{% endcomment %}
