{% extends "socialaccount/signup.html" %}
{% load i18n %}
{% load allauth_ui %}
{% load allauth %}
{% block content %}
    {% trans "Sign Up" as heading %}
    {% blocktrans asvar subheading with provider_name=account.get_provider.name site_name=site.name %}
        You are about to use your {{provider_name}} account to login to {{site_name}}.
        As a final step, please complete the following form:
    {% endblocktrans %}
    {% #container heading=heading subheading=subheading %}
    {% trans "Continue" as button_text %}
    {% url "socialaccount_signup" as url %}
    {% trans "Sign Up" as button_text %}
    {% #form form=form url=url button_text=button_text %}
    {% csrf_token %}
    {{ redirect_field }}
    {% /form %}
    {% /container %}
{% endblock content %}
