{% extends "account/password_reset_done.html" %}
{% load i18n %}
{% load allauth_ui %}
{% block content %}
    {% trans "Password Reset" as heading %}
    {% #container heading=heading %}
    {% if user.is_authenticated %}
        <div class="my-3">{% include "account/snippets/already_logged_in.html" %}</div>
    {% endif %}
    <div>
        {% blocktrans %}We have sent you an email. If you have not received it please check your spam folder. Otherwise contact us if you do not receive it in a few minutes.{% endblocktrans %}
    </div>
    {% /container %}
{% endblock content %}
