{% extends "account/password_reset.html" %}
{% load i18n %}
{% load allauth_ui %}
{% block content %}
    {% trans "Password Reset" as heading %}
    {% #container heading=heading %}
    {% if user.is_authenticated %}
        <div class="my-3">{% include "account/snippets/already_logged_in.html" %}</div>
    {% endif %}
    <div>
        {% trans "Forgotten your password? Enter your email address below, and we'll send you an email allowing you to reset it." %}
    </div>
    {% url "account_reset_password" as url %}
    {% trans "Reset My Password" as button_text %}
    {% #form form=form url=url button_text=button_text %}
    {% csrf_token %}
    {{ redirect_field }}
    {% /form %}
    <div>
        {% blocktrans %}Please contact us if you have any trouble resetting your password.{% endblocktrans %}
    </div>
    {% /container %}
{% endblock content %}
